#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-3ViP42YsElmKsff6l8h8r0
key:                  http-streams-0.8.9.9-3ViP42YsElmKsff6l8h8r0
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  be686a8bbc81510e9120331d6d774b78
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-3ViP42YsElmKsff6l8h8r0
depends:
    HsOpenSSL-0.11.7.10-GkJXz0tt9P7F1l9NnCOJf0
    aeson-2.2.2.0-mVpxNJADFA3tVhrw9PzvG
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7
    attoparsec-aeson-2.2.2.0-D5qY4O0Y7ug3DT7d3V7E7w base-4.18.2.1
    base64-bytestring-1.2.1.0-3MnxOO7xl0P127Exi8mxw2
    blaze-builder-0.4.4.1-4JIC4S953rP8VbASrBgFEC bytestring-0.11.5.3
    case-insensitive-1.2.1.0-42CJmR7jfDI1QxR1AA3Hru directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-LxVVjvG1NfE7hygDVgEr0v
    io-streams-1.5.2.2-Ek00NGLRdErAKRkSN3qZFB mtl-2.3.1
    network-3.1.4.0-Ds5DY5mKlnsDQk8HC4tJQL
    network-uri-2.6.4.2-6IsL4l5xPlJ2SbjqeOZPL6
    openssl-streams-1.2.3.0-5U34VQE6kOg5SSRnxFCexk text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-8KUdGsL7zFhFWAw4aaEQtP

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

